@@ -137,7 +137,7 @@ def parseGemMail_B(gemmail_text = "") -> GemMail:
             pass
         elif line.startswith("<"):
             line = line.removeprefix("<").strip()
-            parts = line.split(" ", 2)
+            parts = line.split(" ", 1)
             sender = GemMailSender()
             if len(parts) == 1:
                 sender = GemMailSender(parts[0], "")
@@ -151,7 +151,7 @@ def parseGemMail_B(gemmail_text = "") -> GemMail:
                 result.Receivers[part] = ()
         elif line.startswith("@"):
             line = line.removeprefix("@").strip()
-            dt = datetime.datetime.strptime(line, '%Y-%m-%dT%H:%M:%S.%f%z')
+            dt = datetime.datetime.strptime(line, '%Y-%m-%dT%H:%M:%S%z')
             result.Timestamps.append(dt)
     result.GemText = parseGemText(gemmail_text)
     result.Subject = result.GemText.firstLevel1Heading
@@ -171,7 +171,7 @@ def parseGemMail_C(gemmail_text = ""):
                 s = s.lstrip()
                 if s == "":
                     continue
-                parts = s.split(None, 2)
+                parts = s.split(None, 1)
                 if len(parts) == 1:
                     gml = GemMailSender(parts[0], "")
                     result.Senders.append(gml)
@@ -191,7 +191,7 @@ def parseGemMail_C(gemmail_text = ""):
                 t = t.strip()
                 if t == "":
                     continue
-                dt = datetime.datetime.strptime(line, '%Y-%m-%dT%H:%M:%S.%f%z')
+                dt = datetime.datetime.strptime(line, '%Y-%m-%dT%H:%M:%S%z')
                 result.Timestamps.append(dt)
     result.GemText = parseGemText(''.join(lines[3:]))
     result.Subject = result.GemText.firstLevel1Heading
